
Changelog
=========

0.2.9 (2015-08-12)
------------------

* Bugfix and small improvements

0.2.8 (2015-08-03)
------------------

* Added testing against Ejabberd 15.07

0.2.7 (2015-07-28)
------------------

* Added API: connected_users
* Added API: connected_users_info
* Added API: connected_users_number
* Added API: user_sessions_info

0.2.6 (2015-07-14)
------------------

* Added API: set_room_affiliation
* Added API: get_room_affiliations

0.2.5 (2015-07-07)
------------------

* Python 2/3 compatibility
* Fixed failing build

0.2.4 (2015-07-06)
------------------

* Made constructor more strict (no more kwargs)
* Added optional function to create a client instance from a service url, compliant with the '12factor app' idea

0.2.3 (2015-06-18)
------------------

* Improved test suite
* Made some enums more explicit
* Aligned MUC room options with currently supported options in Ejabberd, build from master branch

0.2.2 (2015-05-25)
------------------

* Cleanup and more tests

0.2.1 (2015-05-25)
------------------

* Refactored method validator/serializer system


0.2.0 (2015-05-20)
------------------

* Big refactor, interface changed to better match the ejabberdctl interface.

0.1.2 (2015-05-16)
------------------

* Fixed build scripts.

0.1.1 (2015-05-16)
------------------

* Some bugfixes.

0.1.0 (2015-05-16)
------------------

* First release on PyPI.
